# WARNING: Please don't edit this file. It was generated by Python/WinRT v2.2.0

import winrt.system
from winrt import _winrt_windows_management_core

__all__ = [
    "ApplicationDataManager",
]

ApplicationDataManager = _winrt_windows_management_core.ApplicationDataManager



# WARNING: Please don't edit this file. It was generated by Python/WinRT v2.2.0

import datetime
import sys
import types
import typing
import uuid as _uuid
from builtins import property as _property

import winrt._winrt
import winrt.system
import winrt.windows.storage as windows_storage

Self = typing.TypeVar('Self')

@typing.final
class ApplicationDataManager_Static(type):
    def create_for_package_family(cls, package_family_name: str, /) -> typing.Optional[windows_storage.ApplicationData]: ...

@typing.final
class ApplicationDataManager(winrt.system.Object, metaclass=ApplicationDataManager_Static):
    @staticmethod
    def _from(obj: winrt.system.Object, /) -> ApplicationDataManager: ...

